from .gen_convert import GenConverter as GenConverter
from _typeshed import Incomplete

class MetaInspect:
    engine: Incomplete
    schema_name: Incomplete
    support_schema: Incomplete
    inspector: Incomplete
    def __init__(self, *, engine_name: str) -> None: ...
    def get_schema(self, *, schema_name: str) -> dict: ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...
